@@ -1,6 +1,6 @@
 
 # parallel analysis of eigenvalues (no real data required)
-PARALLEL <- function (Nvars=50, Ncases=300, Ndatasets=100, factormodel='PCA', percentile=95,
+PARALLEL <- function (Nvars=50, Ncases=300, Ndatasets=100, extraction='PCA', percentile=95,
                        corkind='pearson', verbose=TRUE){
 evals <- matrix(0, nrow = Nvars, ncol = Ndatasets)
 # pb <- utils::txtProgressBar(min = 0, max = Ndatasets, style = 3) 
@@ -14,13 +14,13 @@ for (nds in 1:Ndatasets) {
 	if (corkind=='spearman')     Rrand <- cor(randat, method='spearman') 
 		
 	# random data eigenvalues
-	if (factormodel=='PCA')  evals[,nds ] <- eigen(Rrand) $values 
-	if (factormodel=='PAF') {
+	if (extraction=='PCA')  evals[,nds ] <- eigen(Rrand) $values 
+	if (extraction=='PAF') {
 		smc = 1 - (1 / diag(solve(Rrand)))
 		diag(Rrand) <- smc
 		evals[,nds] <- eigen(Rrand) $values 
 	}
-	if (factormodel=='image') {
+	if (extraction=='image') {
 		d <-  diag(1 / diag(solve(Rrand)))
 		gvv <- Rrand + d %*% solve(Rrand) %*% d - 2 * d
 		s <- sqrt(d)                  #  Velicer 1974 p 565 formula (7)
@@ -44,9 +44,9 @@ if (verbose == TRUE) {
 	if (corkind=='kendall')    ctype <- 'kendall' 
 	if (corkind=='spearman')   ctype <- 'spearman' 
 	message('\nType of correlations specified for the random data eigenvalues: ', ctype)
-	if (factormodel=='PCA')    message('\nExtraction Method: Principal Components') 
-	if (factormodel=='PAF')    message('\nExtraction Method: Common Factor Analysis')
-	if (factormodel=='image')  message('\nExtraction Method: Image Factor Extraction')
+	if (extraction=='PCA')    message('\nExtraction Method: Principal Components') 
+	if (extraction=='PAF')    message('\nExtraction Method: Common Factor Analysis')
+	if (extraction=='image')  message('\nExtraction Method: Image Factor Extraction')
 	message('\nVariables = ', Nvars) 
 	message('\nCases = ', Ncases) 
 	message('\nNdatasets = ', Ndatasets) 
